@@ -1,6 +1,6 @@
 package PMLTQ::Command::query;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Command::query::VERSION = '1.3.1';
+$PMLTQ::Command::query::VERSION = '1.3.2';
 # ABSTRACT: WIP: Executes query on treebank
 
 use PMLTQ::Base 'PMLTQ::Command';
@@ -18,6 +18,7 @@ use LWP::UserAgent;
 use File::Temp;
 use Encode;
 use Pod::Usage 'pod2usage';
+use JSON;
 
 my $extension_dir;
 my %opts;
@@ -54,6 +55,8 @@ sub run {
   'filters|F=s',
   'no-filters',
 
+  'old-api',
+
   'netgraph-query|G=s',
 
   'print-servers|P',
@@ -87,7 +90,6 @@ sub run {
     $opts{'pmltq-extension-dir'} ||
     File::Spec->catfile($ENV{HOME},'.tred.d','extensions', 'pmltq');
   Treex::PML::AddResourcePath(File::Spec->catfile($extension_dir,'resources'));
-
   if ($opts{ntred}) {
     ntred_search();
   } elsif ($opts{jtred}) {
@@ -221,11 +223,16 @@ sub pmltq_http_search {
 
 
   if ($type eq 'http') {
+    #if($opts{'old-api'}){
     http_search($conf->{url},$query,{ 'node-types'=>$opts{'node-types'},
               'relations'=>$opts{'relations'},
               debug=>$opts{debug},
-              %auth
+              %auth,
+              'old-api'=>$opts{'old-api'}
              });
+    #} else { ## NEW API
+    #  print STDERR "TODO NEW API\n";
+    #}
   } else {
     require PMLTQ::SQLEvaluator;
     my $evaluator = PMLTQ::SQLEvaluator->new(undef,{connect => $conf, debug=>$opts{debug},
@@ -246,7 +253,7 @@ sub pmltq_http_search {
 sub get_server_conf {
   my ($configs,$id)=@_;
   my ($conf,$type);
-  if ($id =~ /^http:/) {
+  if ($id =~ /^https?:/) {
     $type = 'http';
     $conf = {url => $id};
   } else {
@@ -271,15 +278,19 @@ sub http_search {
        $auth{username}, $auth{password})
     if $opts->{username};
   $ua->agent("PMLTQ/1.0 ");
-  $url.='/' unless $url=~m{^https?://.+/};
+  $url.='/' unless $url=~m{^https?://.+/$};
+  my $METHOD = \&POST;
   if ($opts->{'node-types'}) {
-    $url = qq{${url}nodetypes};
+    $url = $opts->{'old-api'} ? qq{${url}nodetypes} : qq{${url}node-types};
+    $METHOD = \&GET unless $opts->{'old-api'};
     $query = '';
   } elsif ($opts->{'relations'}) {
     $url = qq{${url}relations};
+    $METHOD = \&GET unless $opts->{'old-api'};
     $query = '';
   } elsif ($opts->{'other'}) {
     $url = qq{${url}other};
+     die "Unknown option --other in new api\n" unless $opts->{'old-api'};
     $query = '';
   } else {
     $url = qq{${url}query};
@@ -288,18 +299,34 @@ sub http_search {
   my $q = $query; Encode::_utf8_off($q);
   binmode STDOUT;
   my $sub = $opts->{callback} || sub { print $_[0] };
-  my $res = $ua->request(POST($url, [
-      query => $q,
-      format => 'text',
-      limit => $opts{limit},
-      row_limit => $opts{limit},
-      timeout => $opts{timeout},
-     ]),$sub ,1024*8 );
+  my $res = $ua->request($METHOD->($url, 
+    $opts->{'old-api'} ?
+      ([
+        query => $q,
+        format => 'text',
+        limit => $opts{limit},
+        row_limit => $opts{limit},
+        timeout => $opts{timeout},
+       ])
+       :
+       (
+        Content_Type => 'application/json;charset=UTF-8',
+        User_Agent => 'PML-TQ CLI',
+        Content => JSON->new->utf8->encode({
+          query => $q,
+          limit => $opts{limit},
+          # row_limit => $opts{limit}, #TODO: currently not working
+          timeout => $opts{timeout}
+        })
+       )
+     ),$sub ,1024*8 );
   unless ($res->is_success) {
     die $res->status_line."\n".$res->content."\n";
   }
 }
 
+
+
 sub search {
   my ($evaluator,$query)=@_;
   my $results;
@@ -574,7 +601,7 @@ PMLTQ::Command::query - WIP: Executes query on treebank
 
 =head1 VERSION
 
-version 1.3.1
+version 1.3.2
 
 =head1 SYNOPSIS
 
